/****************************************************************************
** Meta object code from reading C++ file 'jscontent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../common/jscontent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jscontent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9JsContentE_t {};
} // unnamed namespace

template <> constexpr inline auto JsContent::qt_create_metaobjectdata<qt_meta_tag_ZN9JsContentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JsContent",
        "callJsInitData",
        "",
        "jsonData",
        "callJsSetHtml",
        "html",
        "callJsInsertVoice",
        "callJsSetVoiceText",
        "text",
        "asrflag",
        "callJsInsertImages",
        "images",
        "callJsSetPlayStatus",
        "status",
        "callJsSetTheme",
        "theme",
        "activeHightColor",
        "disableHightColor",
        "backgroundColer",
        "callJsClipboardDataChanged",
        "calllJsShowEditToolbar",
        "x",
        "y",
        "callJsHideEditToolbar",
        "callJsSetVoicePlayBtnEnable",
        "enable",
        "callJsVoicePlayProgressChanged",
        "progressMs",
        "callJsDeleteSelection",
        "textPaste",
        "isVoicePaste",
        "textChange",
        "loadFinsh",
        "popupMenu",
        "type",
        "QVariant",
        "json",
        "playVoice",
        "bIsSame",
        "playVoiceStop",
        "playVoiceProgressChange",
        "viewPictrue",
        "imagePath",
        "createNote",
        "setDataFinsh",
        "callJsSetFontList",
        "list",
        "font",
        "getfontinfo",
        "scrollTopChange",
        "isTop",
        "jsCallSetDataFinsh",
        "jsCallTxtChange",
        "jsCallChannleFinish",
        "jsCallSummernoteInitFinish",
        "jsCallPopupMenu",
        "jsCallPlayVoice",
        "jsCallPaste",
        "jsCallViewPicture",
        "jsCallCreateNote",
        "jsCallSetClipData",
        "jsCallGetTranslation",
        "jsCallDivTextTranslation",
        "jsCallScrollChange",
        "scrollTop",
        "jsCallPlayVoiceStop",
        "jsCallVoiceProgressChange",
        "onClipChange",
        "QClipboard::Mode",
        "mode",
        "webPath",
        "AsrFlag",
        "Start",
        "End"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'callJsInitData'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'callJsSetHtml'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'callJsInsertVoice'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'callJsSetVoiceText'
        QtMocHelpers::SignalData<void(const QString &, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'callJsInsertImages'
        QtMocHelpers::SignalData<void(const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Signal 'callJsSetPlayStatus'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'callJsSetTheme'
        QtMocHelpers::SignalData<void(int, const QString &, const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'callJsClipboardDataChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calllJsShowEditToolbar'
        QtMocHelpers::SignalData<void(int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Signal 'callJsHideEditToolbar'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'callJsSetVoicePlayBtnEnable'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'callJsVoicePlayProgressChanged'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Signal 'callJsDeleteSelection'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textPaste'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'textChange'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadFinsh'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(int, const QVariant &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Signal 'playVoice'
        QtMocHelpers::SignalData<void(const QVariant &, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Bool, 38 },
        }}),
        // Signal 'playVoiceStop'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playVoiceProgressChange'
        QtMocHelpers::SignalData<void(qint64)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 27 },
        }}),
        // Signal 'viewPictrue'
        QtMocHelpers::SignalData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Signal 'createNote'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setDataFinsh'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'callJsSetFontList'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 46 }, { QMetaType::QString, 47 },
        }}),
        // Signal 'getfontinfo'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollTopChange'
        QtMocHelpers::SignalData<void(const bool &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 50 },
        }}),
        // Slot 'jsCallSetDataFinsh'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallTxtChange'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallChannleFinish'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallSummernoteInitFinish'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallPopupMenu'
        QtMocHelpers::SlotData<void(int, const QVariant &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Slot 'jsCallPlayVoice'
        QtMocHelpers::SlotData<void(const QVariant &, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Bool, 38 },
        }}),
        // Slot 'jsCallPaste'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'jsCallPaste'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'jsCallViewPicture'
        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'jsCallCreateNote'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallSetClipData'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'jsCallGetTranslation'
        QtMocHelpers::SlotData<QString()>(61, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'jsCallDivTextTranslation'
        QtMocHelpers::SlotData<QString()>(62, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'jsCallScrollChange'
        QtMocHelpers::SlotData<void(int)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 64 },
        }}),
        // Slot 'jsCallPlayVoiceStop'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsCallVoiceProgressChange'
        QtMocHelpers::SlotData<void(qint64)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 27 },
        }}),
        // Slot 'onClipChange'
        QtMocHelpers::SlotData<void(QClipboard::Mode)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 68, 69 },
        }}),
        // Method 'webPath'
        QtMocHelpers::MethodData<QString()>(70, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AsrFlag'
        QtMocHelpers::EnumData<enum AsrFlag>(71, 71, QMC::EnumFlags{}).add({
            {   72, AsrFlag::Start },
            {   73, AsrFlag::End },
        }),
    };
    return QtMocHelpers::metaObjectData<JsContent, qt_meta_tag_ZN9JsContentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject JsContent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9JsContentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9JsContentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9JsContentE_t>.metaTypes,
    nullptr
} };

void JsContent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JsContent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->callJsInitData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->callJsSetHtml((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->callJsInsertVoice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->callJsSetVoiceText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->callJsInsertImages((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->callJsSetPlayStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->callJsSetTheme((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 7: _t->callJsClipboardDataChanged(); break;
        case 8: _t->calllJsShowEditToolbar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->callJsHideEditToolbar(); break;
        case 10: _t->callJsSetVoicePlayBtnEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->callJsVoicePlayProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->callJsDeleteSelection(); break;
        case 13: _t->textPaste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->textChange(); break;
        case 15: _t->loadFinsh(); break;
        case 16: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 17: _t->playVoice((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->playVoiceStop(); break;
        case 19: _t->playVoiceProgressChange((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 20: _t->viewPictrue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->createNote(); break;
        case 22: _t->setDataFinsh(); break;
        case 23: _t->callJsSetFontList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->getfontinfo(); break;
        case 25: _t->scrollTopChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->jsCallSetDataFinsh(); break;
        case 27: _t->jsCallTxtChange(); break;
        case 28: _t->jsCallChannleFinish(); break;
        case 29: _t->jsCallSummernoteInitFinish(); break;
        case 30: _t->jsCallPopupMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 31: _t->jsCallPlayVoice((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 32: _t->jsCallPaste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->jsCallPaste(); break;
        case 34: _t->jsCallViewPicture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->jsCallCreateNote(); break;
        case 36: _t->jsCallSetClipData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: { QString _r = _t->jsCallGetTranslation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->jsCallDivTextTranslation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->jsCallScrollChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->jsCallPlayVoiceStop(); break;
        case 41: _t->jsCallVoiceProgressChange((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 42: _t->onClipChange((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1]))); break;
        case 43: { QString _r = _t->webPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QString & )>(_a, &JsContent::callJsInitData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QString & )>(_a, &JsContent::callJsSetHtml, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QString & )>(_a, &JsContent::callJsInsertVoice, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QString & , int )>(_a, &JsContent::callJsSetVoiceText, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QStringList & )>(_a, &JsContent::callJsInsertImages, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(int )>(_a, &JsContent::callJsSetPlayStatus, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(int , const QString & , const QString & , const QString & )>(_a, &JsContent::callJsSetTheme, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::callJsClipboardDataChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(int , int )>(_a, &JsContent::calllJsShowEditToolbar, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::callJsHideEditToolbar, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(bool )>(_a, &JsContent::callJsSetVoicePlayBtnEnable, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(int )>(_a, &JsContent::callJsVoicePlayProgressChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::callJsDeleteSelection, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(bool )>(_a, &JsContent::textPaste, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::textChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::loadFinsh, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(int , const QVariant & )>(_a, &JsContent::popupMenu, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QVariant & , bool )>(_a, &JsContent::playVoice, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::playVoiceStop, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(qint64 )>(_a, &JsContent::playVoiceProgressChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QString & )>(_a, &JsContent::viewPictrue, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::createNote, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::setDataFinsh, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const QStringList & , const QString & )>(_a, &JsContent::callJsSetFontList, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)()>(_a, &JsContent::getfontinfo, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (JsContent::*)(const bool & )>(_a, &JsContent::scrollTopChange, 25))
            return;
    }
}

const QMetaObject *JsContent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JsContent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9JsContentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int JsContent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void JsContent::callJsInitData(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void JsContent::callJsSetHtml(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void JsContent::callJsInsertVoice(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void JsContent::callJsSetVoiceText(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void JsContent::callJsInsertImages(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void JsContent::callJsSetPlayStatus(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void JsContent::callJsSetTheme(int _t1, const QString & _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void JsContent::callJsClipboardDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void JsContent::calllJsShowEditToolbar(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void JsContent::callJsHideEditToolbar()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void JsContent::callJsSetVoicePlayBtnEnable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void JsContent::callJsVoicePlayProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void JsContent::callJsDeleteSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void JsContent::textPaste(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void JsContent::textChange()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void JsContent::loadFinsh()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void JsContent::popupMenu(int _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void JsContent::playVoice(const QVariant & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void JsContent::playVoiceStop()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void JsContent::playVoiceProgressChange(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void JsContent::viewPictrue(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void JsContent::createNote()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void JsContent::setDataFinsh()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void JsContent::callJsSetFontList(const QStringList & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void JsContent::getfontinfo()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void JsContent::scrollTopChange(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}
QT_WARNING_POP
